/**
 * OW2 Util
 * Copyright (C) 2008
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsRepositoryManagerImpl.java 4392 2008-12-15 14:05:41Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.repository.impl;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.ow2.util.plan.bindings.exceptions.InvalidRepositoryException;
import org.ow2.util.plan.bindings.repository.Repository;
import org.ow2.util.plan.repository.api.IRepositoryManager;
import org.ow2.util.plan.repository.api.RepositoryIdCollisionException;

/**
 *
 * @author Mickaël LEDUQUE
 */
public abstract class AbsRepositoryManagerImpl implements IRepositoryManager {

    /**
     * The managed repositories.
     */
    protected Map<String, Repository> repositories = new HashMap<String, Repository>();

    /**
     * {@inheritDoc}
     */
    public void addRepository(final Repository repository)
                    throws RepositoryIdCollisionException, InvalidRepositoryException {
        String repositoryId = repository.getId();
        if (repositoryId == null) {
            throw new InvalidRepositoryException("The repository has no id; repository: "
                    + repository);
        }
        if (this.repositories.containsKey(repositoryId)) {
            throw new RepositoryIdCollisionException("Repository Id already used:"
                    + repositoryId);
        }
        this.repositories.put(repositoryId, repository);
    }

    /**
     * {@inheritDoc}
     */
    public void removeRepository(final Repository repository) {
        /* Must make sure the repository in the manager is the same */
        Repository matchingRepository = this.repositories.get(repository.getId());
        if (repository == matchingRepository) {
            this.repositories.remove(repository.getId());
        }
    }

    /**
     * {@inheritDoc}
     */
    public Repository getRepositoryById(final String id) {
        return this.repositories.get(id);
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<Repository> iterator() {
        Repository[] array = new Repository[repositories.values().size()];
        repositories.values().toArray(array);
        Arrays.sort(array, new RepositoryComparator());
        return Arrays.asList(array).iterator();
    }

    /**
     * {@inheritDoc}
     */
    public Integer getRepositoryCount() {
        return this.repositories.size();
    }
}
