/**
 * OW2 Util
 * Copyright (C) 2008
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: RepositoryComparator.java 4954 2009-05-13 12:15:56Z fornacif $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.repository.impl;

import java.io.Serializable;
import java.util.Comparator;

import org.ow2.util.plan.bindings.repository.Repository;

/**
 * Comparator used to sort repositories. The local repositories are the first
 * repositories returned by the iterator because the repository URL starts with
 * the protocol 'file' (due to lexicographical order).
 * If protocols are equal, repositories are sorted by id.
 * @author Francois Fornaciari
 */
public class RepositoryComparator implements Comparator<Repository>, Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 6156316510585074091L;

    /**
     * Compare two given repositories.
     * @param repository1 the repository to compare
     * @param repository2 the second repository
     * @return compare of the two URLs of the repositories
     */
    public int compare(final Repository repository1, final Repository repository2) {
        // Extracts the repository URL protocols and compare them
        int result = repository1.getUrl().substring(0, 4).compareTo(repository2.getUrl().substring(0, 4));
        if (result == 0) {
            // Compares the repository Ids
            result = repository1.getId().compareTo(repository2.getId());
        }
        return result;
    }
}
